rem ECHO OFF

rem %1 pollutant four-character ID

rem    elem = pollutant 1 = Hg(0)= elemental mercury
rem    HgII = pollutant 2 = Hg(2)= Hg(+2) or "RGM"
rem    Hgpt = pollutant 3 = Hg(p)= particulate Hg, except for Hg2 sorbed to soot)
rem    Hg2s = pollutant 4 = Hg2s = Hg2 sorbed to soot)

rem %2 source lat

rem %3 source long (west is neg)

rem %4 source height (m)

rem %5 number of hours to run

rem %6 number of puffs

rem %7 met data scheme

rem    1 = 2.5 deg global for Aug 2008
rem    2 = edas 40km for Aug 2008
rem    3 = combination of above

rem %8 program code

rem    1 = basic HYSPLIT without GEM
rem    2 = basic HYSPLIT with GEM
rem    3 = HYSPLIT-HG without GEM
rem    4 = HYSPLIT-HG with GEM

rem %9 run name

rem **********************************************************************

del control.dat

rem
rem **********************************************************************
rem    1 - UTC Starting Time for the Simulation (year, month, day, hour)
rem **********************************************************************

rem    two-digit values for the UTC time that the calculation is to start
rem    Enter 0's to start at the beginning (or end) of the initial met file,
rem    depending on the direction of the calculation

rem    Default:  0 0 0 0

rem    All zero values in this field will force the calculation to use the time
rem    of the first (or last) record of the meteorological data file.  In the special
rem    case where year and month are zero, day and hour are treated as relative to the
rem    start or end of the file.  For example, the first record of the meteorological
rem    data file usually starts at 0000 UTC.  An entry of  00 00 01 12 would start
rem    the calculation 36 hours from the start of the data file.

rem ECHO 00 00 00 00 >CONTROL.DAT
rem  ECHO 99 01 01 00 >CONTROL.DAT

rem ECHO 04 01 01 00 >CONTROL.DAT

rem normal starting time
ECHO 08 08 01 00 >CONTROL.DAT

rem set to start day two
rem ECHO 08 08 02 00 >CONTROL.DAT

rem temporarily set to day three for short test
rem ECHO 08 08 03 00 >CONTROL.DAT

rem **********************************************************************
rem    2 - Number of Starting Locations
rem **********************************************************************

rem    Default: 1

rem    Single or multiple pollutant sources may be simultaneously tracked.
rem    The emission rate that is specified in the pollutant menu is assigned
rem    to each source.  If multiple sources are defined at the same location,
rem    the emissions are distributed vertically in a layer between the current
rem    emission height and the previous source emission height. The effective
rem    source will be a vertical line source between the two heights.
rem    When multiple sources are in different locations, the pollutant
rem    is emitted as a point source from each location at the height specified.
rem    Point and vertical line sources can be mixed in the same simulation.
rem    Area source emissions can be specified from an input file: emission.txt.
rem    When this file is present in the root directory, the emission parameters
rem    in the Control file are superceded by the emission rates specified in the file.
rem    More information on this file structure can be found in the advanced help section.

ECHO 1 >>CONTROL.DAT

rem *******************************************************************************
rem    3(1) - Starting Location: lat,long, height (meters above ground), Opt-4, Opt-5
rem *******************************************************************************
rem    Default:  40.0 -90.0 50.0

rem    Position in degrees and decimal (West and South are negative).

rem    Height is entered as meters above ground level unless the
rem    mean-sea-level flag has been set.

rem    The optional 4th (emission rate - units per hour) and
rem    5th (emission area - square meters) columns on this input line
rem    can be used to supercede the value of the emission rate (line 12-2)
rem    when multiple sources are defined, otherwise all sources have the same rate
rem    as specified on line 12-2. The 5th column defines the virtual size of the source:
rem    point sources default to 0".

rem ECHO 45.0 -93.0 50.0 >>CONTROL.DAT
ECHO %2 %3 %4 >>CONTROL.DAT

rem **********************************************************************
rem    4 - Total Run Time for Simulation (hours)
rem **********************************************************************
rem    default = 48

rem    Sets the duration of the calculation in hours.
rem    Backward calculations are configured by setting the run time to a negative value.
rem    See the discussion in the advanced help section on backward dispersion calculations.

ECHO %5 >>CONTROL.DAT

rem **********************************************************************
rem    5 - Method for Estimating Vertical Motion
rem **********************************************************************

rem    0:data=model's vertical velocity fields;
rem    1:isob 2:isen 3:dens 4:sigma 5:diverg 6:eta
rem    Default:  0

rem    Indicates the vertical motion calculation method.
rem    The default data selection will use the meteorological model's
rem    vertical velocity fields; other options include isobaric, isentropic,
rem    constant density, constant internal sigma coordinate, computed
rem    from the velocity divergence, and a special transformation to correct
rem    the vertical velocities when mapped from quasi-horizontal ETA surfaces
rem    to HYSPLITs internal terrain following sigma coordinate.

ECHO 0 >>CONTROL.DAT

rem **********************************************************************
rem    6 - Top of model domain (internal coordinates m-agl)
rem **********************************************************************

rem    Default:  10000.0

rem    Sets the vertical limit of the internal meteorological grid.

rem    If calculations are not required above a certain level, fewer meteorological
rem    data are processed thus speeding up the computation.  Trajectories will terminate
rem    when they reach this level.

rem    A secondary use of this parameter is to set the models internal
rem    scaling height  the height at which the internal sigma surfaces go flat
rem    relative to terrain.  The default internal scaling height is set to 25 km
rem    but it is set to the top of the model domain if the entry exceeds 25 km.
rem    Further, when meteorological data are provided on terrain sigma surfaces
rem    it is assumed that the input data were scaled to a height of 20 km (RAMS)
rem    or 34.8 km (COAMPS).  If a different height is required to decode the input data,
rem    it should be entered on this line as the negative of the height.
rem    HYSPLITs internal scaling height remains at 25 km unless the absolute value
rem    of the domain top exceeds 25 km.

rem ECHO 10000.0 >>CONTROL.DAT
ECHO 25000.0 >>CONTROL.DAT

rem **********************************************************************
rem    7 - Number of input data grids
rem **********************************************************************

rem    Default:  1

rem    Number of simultaneous input meteorological files.
rem    The following two entries (directory and name) will be repeated this number of times.
rem    A simulation will terminate when the computation is off all of the grids in either
rem    space or time.  Calculations will check the grid each time step and use the
rem    finest resolution input data available at that location at that time.
rem    When multiple meteorological grids have different resolution, there is an
rem    additional restriction that there should be some overlap between the grids in time,
rem    otherwise it is not possible to transfer a particle position from one grid to another.

rem ECHO 1 >>CONTROL.DAT

rem **********************************************************************
rem    8(1) - Meteorological data grid # 1 directory
rem **********************************************************************

rem		 Default: ( \main\sub\data\ )

rem    Directory location of the meteorological file on the grid specified.
rem    Always terminate with the appropriate slash (\ or /).

rem ECHO c:\hysplit4\metdata\ >>CONTROL.DAT

rem **********************************************************************
rem    9(2) - Meteorological data grid # 1 file name
rem **********************************************************************

rem    Default:  file_name

rem    Name of the file containing meteorological data.  Located in the previous directory.

rem ECHO RP200401.gbl >>CONTROL.DAT
rem ECHO oct1618.bin >>CONTROL.DAT

rem -------------------------
rem    met data schemes
rem -------------------------

if %7==1 goto met_1
if %7==2 goto met_2
if %7==3 goto met_3

rem ---------------------------------------
:met_1

ECHO 1 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO RP200808.gbl >>CONTROL.DAT

goto met_end

rem ---------------------------------------
:met_2

ECHO 2 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO edas.aug08.001 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO edas.aug08.002 >>CONTROL.DAT

goto met_end

rem ---------------------------------------
:met_3

ECHO 3 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO edas.aug08.001 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO edas.aug08.002 >>CONTROL.DAT

ECHO c:\hysplit4\metdata\ >>CONTROL.DAT
ECHO RP200808.gbl >>CONTROL.DAT

goto met_end

:met_end

rem **********************************************************************
rem    10 - Number of different pollutants
rem **********************************************************************

rem    Default:  1

rem    Multiple pollutant species may be defined for emissions.
rem    Each pollutant is assigned to its own particle or puff and therefore may
rem    behave differently due to deposition or other pollutant specific characteristics.
rem    Each will be tracked on its own concentration grid.  The following four entries
rem    are repeated for each pollutant defined.

rem    MDC NOTE -- this has been "4" in Hg simulations to date...

rem ECHO 1 >>CONTROL.DAT
ECHO 4 >>CONTROL.DAT

rem here is the template, with descriptions of data

rem **********************************************************************
rem    11(1) - Pollutant four Character Identification
rem **********************************************************************

rem    Default:  TEST

rem    Provides a four-character label that can be used to identify the pollutant.
rem    The label is written with the concentration output grid to identify output
rem    records associated with that pollutant and will appear in display labels.
rem    Additional user supplied deposition and chemistry calculations may be keyed
rem    to this identification string.

rem ECHO TEST >>CONTROL.DAT

rem **********************************************************************
rem    12(2) - Emission rate (per hour)
rem **********************************************************************

rem    Default:  1.0

rem    Mass units released each hour.  Units are arbitrary except when specific
rem    chemical transformation subroutines are associated with the calculation.
rem    Output air concentration units will be in the same units as specified on this line.
rem    For instance an input of kg/hr results in an output of kg/m3.

rem    When multiple sources are defined this rate is assigned to all sources unless
rem    the optional parameters are present on line 3(1).

rem ECHO 1.0 >>CONTROL.DAT

rem **********************************************************************
rem    13(3)- Hours of emission
rem **********************************************************************

rem    Default:  1.0

rem    The duration of emission may be defined in fractional hours.  An emission
rem    duration of less than one time-step will be emitted over one time-step with
rem    a total emission that would yield the requested rate over the emission duration.

rem ECHO 1.0 >>CONTROL.DAT

rem **********************************************************************
rem    14(4)- Release start time:  year month day hour minute
rem **********************************************************************

rem    Default:  [simulation start]

rem    The previously specified hours of emission start at this time.  An entry of
rem    zeros in the field, when input is read from a file, will also result in the
rem    selection of the default values that will correspond with the starting time
rem    of the meteorological data file.  Day and hour are treated as relative to the
rem    file start when month is set to zero.

rem ECHO 00 00 00 00 00 >>CONTROL.DAT

rem **********************************************************************
rem    NOTE... Temporal or Area Emission Variations... Unless additional input values are
rem    provided in the control file after each emission location, the same rate will apply
rem    to all defined point sources for the duration of the emission.  When more complex
rem    emission scenarios are required, emission data can be read in from a file that defines
rem    a diurnal emission cycle for any number of pollutants at any number of locations.
rem    If the emission rate is to vary in time beyond one diurnal cycle, there is another
rem    input file that can be defined to set a new rate with each emission cycle.
rem    In this latter scenario the rate as well as the location may be changed.
rem **********************************************************************

rem if %1==elem goto elem_spec
rem if %1==HgII goto HgII_spec
rem if %1==Hgpt goto Hgpt_spec
rem if %1==Hg2s goto Hg2s_spec

rem #######################################
:elem_spec
rem values for pollutant 1 Hg0
rem #######################################

rem **********************************************************************
rem    11(1) - Pollutant four Character Identification
rem **********************************************************************
ECHO elem >>CONTROL.DAT
rem **********************************************************************
rem    12(2) - Emission rate (per hour)
rem **********************************************************************
if %1==elem goto elemrat1
if %1==HgII goto HgIIrat1
if %1==Hgpt goto Hgptrat1
if %1==Hg2s goto Hg2srat1

:elemrat1

ECHO 1.0 >>CONTROL.DAT
goto end121
:HgIIrat1

ECHO 0.0 >>CONTROL.DAT
goto end121
:Hgptrat1

ECHO 0.0 >>CONTROL.DAT
goto end121
:Hg2srat1

ECHO 0.0 >>CONTROL.DAT
goto end121

:end121

rem **********************************************************************
rem    13(3)- Hours of emission
rem **********************************************************************
rem   used to have 1 hour of emissions
rem   now will have 1/10 hour emissions at 10x the intensity
rem ECHO 1.0 >>CONTROL.DAT
ECHO 0.1 >>CONTROL.DAT
rem **********************************************************************
rem    14(4)- Release start time:  year month day hour minute
rem **********************************************************************
ECHO 00 00 00 00 00 >>CONTROL.DAT
rem **********************************************************************

rem goto end_spec

rem #######################################
:HgII_spec
rem values for pollutant 1 Hg2
rem #######################################

rem **********************************************************************
rem    11(1) - Pollutant four Character Identification
rem **********************************************************************
ECHO HgII >>CONTROL.DAT
rem **********************************************************************
rem    12(2) - Emission rate (per hour)
rem **********************************************************************
if %1==elem goto elemrat2
if %1==HgII goto HgIIrat2
if %1==Hgpt goto Hgptrat2
if %1==Hg2s goto Hg2srat2

:elemrat2
ECHO 0.0 >>CONTROL.DAT
goto end122

:HgIIrat2
ECHO 1.0 >>CONTROL.DAT
goto end122

:Hgptrat2
ECHO 0.0 >>CONTROL.DAT
goto end122

:Hg2srat2
ECHO 0.0 >>CONTROL.DAT
goto end122

:end122
rem **********************************************************************
rem    13(3)- Hours of emission
rem **********************************************************************
rem   will have 0.1 hour of emissions at 10x intensity
ECHO 0.1 >>CONTROL.DAT
rem **********************************************************************
rem    14(4)- Release start time:  year month day hour minute
rem **********************************************************************
ECHO 00 00 00 00 00 >>CONTROL.DAT
rem **********************************************************************

rem goto end_spec

rem #######################################
:Hgpt_spec
rem values for pollutant 3 Hgp
rem #######################################

rem **********************************************************************
rem    11(1) - Pollutant four Character Identification
rem **********************************************************************
ECHO Hgpt >>CONTROL.DAT
rem **********************************************************************
rem    12(2) - Emission rate (per hour)
rem **********************************************************************
if %1==elem goto elemrat3
if %1==HgII goto HgIIrat3
if %1==Hgpt goto Hgptrat3
if %1==Hg2s goto Hg2srat3

:elemrat3
ECHO 0.0 >>CONTROL.DAT
goto end123

:HgIIrat3
ECHO 0.0 >>CONTROL.DAT
goto end123

:Hgptrat3
ECHO 1.0 >>CONTROL.DAT
goto end123

:Hg2srat3
ECHO 0.0 >>CONTROL.DAT
goto end123

:end123
rem **********************************************************************
rem    13(3)- Hours of emission
rem **********************************************************************
rem   will have 0.1 hour of emissions at 10x intensity
ECHO 0.10 >>CONTROL.DAT
rem **********************************************************************
rem    14(4)- Release start time:  year month day hour minute
rem **********************************************************************
ECHO 00 00 00 00 00 >>CONTROL.DAT
rem **********************************************************************

rem goto end_spec

rem #######################################
:Hg2s_spec
rem values for pollutant 4 Hg2s
rem #######################################

rem **********************************************************************
rem    11(1) - Pollutant four Character Identification
rem **********************************************************************
ECHO Hg2s >>CONTROL.DAT
rem **********************************************************************
rem    12(2) - Emission rate (per hour)
rem **********************************************************************
if %1==elem goto elemrat4
if %1==HgII goto HgIIrat4
if %1==Hgpt goto Hgptrat4
if %1==Hg2s goto Hg2srat4

:elemrat4
ECHO 0.0 >>CONTROL.DAT
goto end124

:HgIIrat4
ECHO 0.0 >>CONTROL.DAT
goto end124

:Hgptrat4
ECHO 0.0 >>CONTROL.DAT
goto end124

:Hg2srat4
ECHO 1.0 >>CONTROL.DAT
goto end124

:end124

rem **********************************************************************
rem    13(3)- Hours of emission
rem **********************************************************************
rem   will have 0.1 hour of emissions at 10x intensity
ECHO 0.1 >>CONTROL.DAT
rem **********************************************************************
rem    14(4)- Release start time:  year month day hour minute
rem **********************************************************************
ECHO 00 00 00 00 00 >>CONTROL.DAT
rem **********************************************************************

rem goto end_spec

:end_spec

rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************
rem    This section is used to define the grid system to which the concentrations are
rem    summed during the integration and subsequently for post-processing and display
rem    of the models output.  There are 10 entries in the CONTROL file for each
rem    concentration grid that has been defined.  The lines 16(1) through 25(10)
rem    correspond with each of the menu items shown in the illustration below.

rem    Dispersion calculations are performed on the computational (meteorological) grid
rem    without regard to the definition or location of any concentration grid.  Therefore
rem    it is possible to complete a simulation and have no results to view if the
rem    concentration grid was in the wrong location.  In addition, very small concentration
rem    grid spacing will reduce the models integration time step and may result in
rem    substantially longer simulation clock times.
rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************

goto conc_1
rem goto conc_4

:conc_1

rem **********************************************************************
rem    15- Number of simultaneous concentration grids
rem **********************************************************************
rem    Default: 1

rem    Multiple or nested grids may be defined.  The concentration output grids are
rem    treated independently.  The following 10 entries will be repeated for each grid defined.
rem    Due to unit number restrictions, the current compilation version is limited to a
rem    maximum of 9 grids.

ECHO 1 >>CONTROL.DAT
rem ECHO 4 >>CONTROL.DAT

rem **********************************************************************
rem DATA FOR GRID #1
rem  in set 20, changed spacing from 0.1, 0.1, and span 5, 5 to
rem  spacing of 0.5 and span 10
rem
rem **********************************************************************

rem -------------------------------------------------------------
rem    16(1)- Center Latitude, Longitude (degrees)
ECHO 0.0  0.0  >>CONTROL.DAT
rem -------------------------------------------------------------
rem    17(2)- Grid spacing (degrees) Latitude, Longitude

ECHO 0.1  0.1  >>CONTROL.DAT
rem ECHO 0.5  0.5  >>CONTROL.DAT
rem -------------------------------------------------------------
rem    18(3)- Grid span (deg) Latitude, Longitude
ECHO 5.0  5.0 >>CONTROL.DAT
rem -------------------------------------------------------------
rem    19(4)- Grid directory
ECHO .\ >>CONTROL.DAT
rem -------------------------------------------------------------
rem    20(5)- Grid file name
ECHO cdump.bin >>CONTROL.DAT
rem -------------------------------------------------------------
rem    21(6)- Number of vertical concentration levels
rem ECHO 5 >>CONTROL.DAT
ECHO 6 >>CONTROL.DAT
rem -------------------------------------------------------------
rem    22(7)- Height of each level (m)
rem ECHO 0.0  10.0  100.0  1000.0 10000.0 >>CONTROL.DAT
rem in order to meaningfully add GEM output to CDUMP output, the vertical heights must be the "same"
rem the heights in the met data -- hence GEM -- are not constant, as they are based on pressure
rem The heights below are approximate
rem NOTE -- in first version of CONCADD, there had to be the same number of levels
rem in CDUMP and GDUMP files, so here, have the same number (see GEMPARM below)
rem in new version of CONCADD, don't have to have the same number of levels,
rem but it still adds based on vertical index, not height

ECHO 0.0  200.0  850.0  1550.0  3000.0  4400.0 >>CONTROL.DAT

rem -------------------------------------------------------------
rem    23(8)- Sampling start time:  year month day hour minute
ECHO 00 00 00 00 00 >>CONTROL.DAT
rem -------------------------------------------------------------
rem    24(9)- Sampling stop time:  year month day hour minute
ECHO 20 12 31 24 60 >>CONTROL.DAT
rem -------------------------------------------------------------
rem    25(10)- Sampling interval:  type hour minute
ECHO 00 24 00 >>CONTROL.DAT
rem ------------------------------------------------------------

rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************
rem    This next section is used to define the deposition parameters for emitted
rem    pollutants. The number of deposition definitions must correspond with
rem    the number of pollutants released.  There is a one-to-one correspondence.
rem    There are 5 entries in the CONTROL file for each defined pollutant.
rem    The lines 27(1) through 31(5) correspond with each of the menu items
rem    shown in the illustration below.
rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************

rem **********************************************************************
rem    26- Number of pollutants depositing
rem **********************************************************************

rem    Default: number of pollutants on line # 10

rem    Deposition parameters must be defined for each pollutant species emitted.
rem    Each species may behave differently for deposition calculations.  Each will
rem    be tracked on its own concentration grid.  The following five lines are
rem    repeated for each pollutant defined.  The number here must be identical
rem    to the number on line 10.  Deposition is turned off for pollutants by an
rem    entry of zero in all fields.

rem    MDC NOTE: this has been "4" in Hg simulations to date...

rem ECHO 1 >>CONTROL.DAT
ECHO 4 >>CONTROL.DAT

rem pollutant 1 is Hg0  (elemental mercury)
rem pollutant 2 is Hg2  (Hg+2 or "RGM")
rem pollutant 3 is Hgp  (particulate Hg, except for Hg2 sorbed to soot)
rem pollutant 4 is Hg2s (Hg2 sorbed to soot)

rem here is the template, with descriptions...

rem **********************************************************************
rem    27(1)- Particle:  Diameter (m), Density (g/cc), and Shape
rem **********************************************************************

rem    Default:  0.0 0.0 0.0

rem    These three entries are used to define the pollutant as a particle
rem    for gravitational settling and wet removal calculations.  A value of
rem    zero in any field will cause the pollutant to be treated as a gas.
rem    All three fields must be defined (>0) for particle deposition
rem    calculations.  However, these values only need to be correct only
rem    if gravitational settling or resistance deposition is to be computed
rem    by the model. Otherwise a nominal value of 1.0 may be assigned as the
rem    default for each entry to define the pollutant as a particle.
rem    If a dry deposition velocity is specified as the first entry in
rem    the next line (28), then that value is used as the particle settling
rem    velocity rather than the value computed from the particle diameter
rem    and density.

rem ECHO 0.0  0.0  0.0 >>CONTROL.DAT

rem **********************************************************************
rem    28(2)- Deposition velocity (m/s),
rem           Pollutant molecular weight (Gram/Mole),
rem           Surface Reactivity Ratio,
rem           Diffusivity Ratio,
rem           Effective Henrys Constant
rem **********************************************************************

rem    Default:  0.0 0.0 0.0 0.0 0.0

rem    Dry deposition calculations are performed in the lowest model layer
rem    based upon the relation that the deposition flux equals the velocity
rem    times the ground-level air concentration.  This calculation is
rem    available for gases and particles.  The dry deposition velocity
rem    can be set directly for each pollutant by entering a non-zero value
rem    in the first field.  The velocity can also be calculated by the model
rem    using the resistance method which requires setting the remaining four
rem    parameters (molecular weight, surface reactivity, diffusivity, and
rem    the effective Henrys constant). There's a table in the user's manual
rem    with some example values... .

rem ECHO 0.0  0.0  0.0  0.0  0.0 >>CONTROL.DAT

rem **********************************************************************
rem    29(3)- Wet Removal: Actual Henry's constant,
rem           In-cloud (L/L), Below-cloud (1/s)
rem **********************************************************************

rem    Default:  0.0 0.0 0.0
rem    Suggested: 0.0  3.2E+05   5.0E-05

rem    Henry's constant defines the wet removal process for soluble gases.
rem    It is defined only as a first-order process by a non-zero value in
rem    the field.  Wet removal of particles is defined by non-zero values
rem    for the in-cloud and below-cloud parameters.  In-cloud removal is
rem    defined as a ratio of the pollutant in air (g/liter of air in the
rem    cloud layer) to that in rain (g/liter) measured at the ground.
rem    Below-cloud removal is defined through a removal time constant.

rem    MDC NOTE: I wonder why Roland has distinguished the Henry's constant
rem    as "actual"... I think it should probably be "effective" like in
rem    above parameter specification on line #28...

rem ECHO 0.0  3.2E+05  5.0E-05 >>CONTROL.DAT

rem **********************************************************************
rem    30(4)- Radioactive decay half-life (days)
rem **********************************************************************

rem    Default: 0.0

rem    A non-zero value in this field initiates the decay process of both
rem    airborne and deposited pollutants.

rem ECHO 0.0 >>CONTROL.DAT

rem **********************************************************************
rem    31(5)- Pollutant Resuspension (1/m)
rem **********************************************************************

rem    Default: 0.0
rem    Suggested :1.0E-06

rem    A non-zero value for the re-suspension factor causes deposited
rem    pollutants to be re-emitted based upon soil conditions, wind velocity,
rem    and particle type.  Pollutant re-suspension requires the definition
rem    of a deposition grid, as the pollutant is re-emitted from previously
rem    deposited material.  Under most circumstances, the deposition should
rem    be accumulated on the grid for the entire duration of the simulation.
rem    Note that the air concentration and deposition grids may be defined at
rem    different temporal and spatial scales.

rem ECHO 0.0 >>CONTROL.DAT

rem if %1==elem goto elem_prop
rem if %1==HgII goto HgII_prop
rem if %1==Hgpt goto Hgpt_prop
rem if %1==Hg2s goto Hg2s_prop

rem #######################################
:elem_prop
rem values for pollutant 1 Hg0
rem #######################################

rem **********************************************************************
rem    27(1)- Particle:  Diameter (m), Density (g/cc), and Shape
rem **********************************************************************
ECHO 0.0  2.0  1.0 >>CONTROL.DAT
rem **********************************************************************
rem    28(2)- Deposition velocity (m/s),
rem           Pollutant molecular weight (Gram/Mole),
rem           Surface Reactivity Ratio,
rem           Diffusivity Ratio,
rem           Effective Henrys Constant
rem **********************************************************************
rem  don't really know diffusivity ratio... assume that it's 2 for now
rem ECHO   0.0   200.6    0.1    2.0    0.11  >>CONTROL.DAT
rem changed F0 surf react ratio to 0 Dec 2, 2004
ECHO 0.0   200.6    0.0    2.0    0.11  >>CONTROL.DAT
rem **********************************************************************
rem    29(3)- Wet Removal: Actual Henry's constant,
rem           In-cloud (L/L), Below-cloud (1/s)
rem **********************************************************************
ECHO 0.11     4.0E+04    5.0E-05 >>CONTROL.DAT
rem **********************************************************************
rem    30(4)- Radioactive decay half-life (days)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************
rem    31(5)- Pollutant Resuspension (1/m)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************

rem goto end_prop

rem #######################################
:HgII_prop
rem values for pollutant 2 Hg2
rem #######################################

rem **********************************************************************
rem    27(1)- Particle:  Diameter (m), Density (g/cc), and Shape
rem **********************************************************************
ECHO 0.0   2.0   1.0 >>CONTROL.DAT
rem **********************************************************************
rem    28(2)- Deposition velocity (m/s),
rem           Pollutant molecular weight (Gram/Mole),
rem           Surface Reactivity Ratio,
rem           Diffusivity Ratio,
rem           Effective Henrys Constant
rem **********************************************************************
ECHO 0.0   271.5    1.0    2.0    1.4E+06 >>CONTROL.DAT
rem **********************************************************************
rem    29(3)- Wet Removal: Actual Henry's constant,
rem           In-cloud (L/L), Below-cloud (1/s)
rem **********************************************************************
ECHO 1.4E+06    4.0E+04    5.0E-05 >>CONTROL.DAT
rem **********************************************************************
rem    30(4)- Radioactive decay half-life (days)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************
rem    31(5)- Pollutant Resuspension (1/m)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************

rem goto end_prop

rem #######################################
:Hgpt_prop
rem values for pollutant 3 Hgp
rem #######################################

rem **********************************************************************
rem    27(1)- Particle:  Diameter (m), Density (g/cc), and Shape
rem **********************************************************************
ECHO 1.0   2.0   1.0 >>CONTROL.DAT
rem **********************************************************************
rem    28(2)- Deposition velocity (m/s),
rem           Pollutant molecular weight (Gram/Mole),
rem           Surface Reactivity Ratio,
rem           Diffusivity Ratio,
rem           Effective Henrys Constant
rem **********************************************************************
rem this pollutant in particle phase only, so these parameters are irrelevant
rem will just dummy them in here
ECHO 0.0   271.5    1.0    2.0    1.4E+06 >>CONTROL.DAT
rem **********************************************************************
rem    29(3)- Wet Removal: Actual Henry's constant,
rem           In-cloud (L/L), Below-cloud (1/s)
rem **********************************************************************
rem this pollutant in particle phase so Henry's constant not relevant
rem will just dummy it in here
ECHO 0.11    4.0E+04    5.0E-05 >>CONTROL.DAT
rem **********************************************************************
rem    30(4)- Radioactive decay half-life (days)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************
rem    31(5)- Pollutant Resuspension (1/m)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************

rem goto end_prop

rem #######################################
:Hg2s_prop
rem values for pollutant 4 Hg2s
rem #######################################

rem **********************************************************************
rem    27(1)- Particle:  Diameter (m), Density (g/cc), and Shape
rem **********************************************************************
ECHO 1.0   2.0   1.0 >>CONTROL.DAT
rem **********************************************************************
rem    28(2)- Deposition velocity (m/s),
rem           Pollutant molecular weight (Gram/Mole),
rem           Surface Reactivity Ratio,
rem           Diffusivity Ratio,
rem           Effective Henrys Constant
rem **********************************************************************
rem this pollutant in particle phase only, so these parameters are irrelevant
rem will just dummy them in here
ECHO 0.0   271.5    1.0    2.0    1.4E+06 >>CONTROL.DAT
rem **********************************************************************
rem    29(3)- Wet Removal: Actual Henry's constant,
rem           In-cloud (L/L), Below-cloud (1/s)
rem **********************************************************************
rem this pollutant in particle phase so Henry's constant not relevant
rem will just dummy it in here
ECHO 0.11    4.0E+04    5.0E-05 >>CONTROL.DAT
rem **********************************************************************
rem    30(4)- Radioactive decay half-life (days)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************
rem    31(5)- Pollutant Resuspension (1/m)
rem **********************************************************************
ECHO 0.0 >>CONTROL.DAT
rem **********************************************************************

rem goto end_prop

:end_prop

rem    ok... done establishing the CONTROL file...
rem pause

del control.
rename control.dat control.

rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************
rem   ESTABLISH SETUP.CFG FILE
rem **********************************************************************
rem   The SETUP.CFG namelist file is not required, and if not present in the root
rem   startup directory, default values are used.  These parameters can all be
rem   changed without recompilation by modification of the contents of SETUP.CFG
rem   and in some cases their modification will substantially change the nature
rem   of the simulation. The configuration file should be present in the root
rem   directory.

rem **********************************************************************
rem  NEW VERSION OF SETUP NAMELIST October 2008
rem **********************************************************************

rem ! special simulation setup parameters read from namelist
rem   NAMELIST/SETUP/INITD,KHMAX,NUMPAR,MAXPAR,MAXDIM,QCYCLE,P10F,KMIXD,KMIX0,     &
rem                  FRME,FRMR,KRND,DELT,KDEF,TKERD,TKERN,NDUMP,NCYCL,TRATIO,ISOT, &
rem                  MGMIN,KMSL,NSTR,MHRS,NVER,CPACK,CMASS,ICHEM,EFILE,VSCALE,     &
rem                  TOUT,TM_PRES,TM_TPOT,TM_TAMB,TM_RAIN,TM_MIXD,TM_TERR,HSCALE,  &
rem                  TM_DSWF,TM_RELH,DXF,DYF,DZF,PINPF,POUTF,NINIT,KAGL,KPUFF,     &
rem                  KBLT,KZMIX,TVMIX,KBLS,CONAGE,KSPL,FRHS,FRVS,FRTS,FRHMAX,SPLITF

rem NEW OR CHANGED PARAMETERS ARE:
rem ISOT is in namelist, but not used
rem KBLT has been added
rem KZMIX has been added
rem TVMIX has been added

rem KPBL has been deleted
rem KZAV has been deleted

del setup.txt

ECHO  ^&SETUP > setup.txt
rem now figured out how to ECHO an ampersand -- have to have a ^ in front!

rem ---------------------------------------------------------------------------------
rem   Model Type
rem   INITD (4) - determines if the model is configured as a puff or particle model.
rem   Valid options are:
rem   0 - Horizontal and Vertical Particle
rem   1 - Horizontal Gaussian Puff, Vertical Top Hat Puff
rem   2 - Horizontal and Vertical Top Hat Puff
rem   3 - Horizontal Gaussian Puff, Vertical Particle
rem   4 - Horizontal Top-Hat Puff, Vertical Particle (DEFAULT)

rem   Introduced with the September 2004 version are mixed model calculations,
rem   but not yet available through the GUI:
rem   103 - converts 3D particle #0 to #3
rem   104 - converts 3D particle #0 to #4
rem   130 - converts #3 to #0 3D particle
rem   140 - converts #4 to #0 3D particle

rem   The conversions occur automatically in mixed mode when the horizontal
rem   standard deviation of the puff (or particle equivalent) equals the
rem   concentration grid size.  A use of this approach might be for a long-range
rem   or regional puff simulation, where the concentration grid is rather coarse.
rem   In this case the puffs may pass between concentration sampling nodes during
rem   the initial stages of the transport, a stage when the plume is still narrow.
rem   Using mode #104 would start the simulation with particles (and concentration
rem   grid cells) and then switch to puff mode (and concentration sampling nodes)
rem   when the particles are distributed over a concentration grid cell.

rem   NOTE: I have been using option #2 (puff in horiz and vert) up to this point
rem   with new GEM code, need to set this to a conversion number (i.e., > 100)
rem   For example, INITD = 129
rem   This means that its a conversion (the first digit)
rem   it means that it starts out as a puff (the 2nd digit = 2)
rem   and the third digit is what is converts to... in this case,
rem   "9" is undefined, but, this will work for conversion to GEM grid
rem   if the third digit was defined, then it would convert to defined entity

rem ECHO  INITD   = 2,       >>SETUP.TXT
ECHO  INITD   = 129,       >>SETUP.TXT
rem ECHO  INITD   = 109,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KHMAX (9999) - is the maximum age (in hours) that any puff or particle
rem   is permitted to attain.  All pollutants beyond this age are deleted.

ECHO  KHMAX   = 9999,    >>SETUP.TXT
rem ---------------------------------------------------------------------------------
rem   NUMPAR (500) - would be the maximum number of particles or puffs released.
rem   NUMPAR has a different meaning for puff and particle simulations.  In a full
rem   puff simulation (INITD=1,2), only one puff per time step is released,
rem   regardless of the value of NUMPAR.  In a particle or mixed particle-puff
rem   simulation (INITD=0,3,4), NUMPAR represents the total number of particles that
rem   are released during one release cycle.  Multiple release cycles cannot produce
rem   more than MAXPAR number of particles.  For a mixed simulation (particle-puff),
rem   NUMPAR should be greater than one but does not need to be anything close to what
rem   is required for a full 3D particle simulation.  In all simulation types, particle
rem   or puffs are emitted if the particle count is less than MAXPAR.

rem   there may be a bug in HYSPLIT in pufsph... to get around this,
rem   will set numpar = maxpar for my runs...

rem ECHO  NUMPAR  = 1000,     >>SETUP.TXT
ECHO  NUMPAR  = %6,     >>SETUP.TXT
rem ECHO  NUMPAR  = 10,     >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   MAXPAR (10000) - is the maximum number of particles permitted to be carried
rem   at any time during a simulation.
rem   MDC NOTE: in most simulation to date, I have typically used MAXPAR = 1000

rem ECHO  MAXPAR  = 10000,   >>SETUP.TXT
ECHO  MAXPAR  = %6,   >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   MAXDIM (1) - is the maximum number of pollutants that can be attached to one
rem   particle.  Otherwise, if multiple pollutants are defined they are released
rem   as individual particles.  This feature is only required with chemical
rem   conversion modules and is not implemented in the public distribution version.

rem   MDC NOTE: MAXDIM = 4 for Hg simulations, with 4 different
rem   types of mercury (elem, oxid, part, sorbed) in each puff

rem ECHO  MAXDIM  = 1,       >>SETUP.TXT
ECHO  MAXDIM  = 4,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   QCYCLE (0.0) - Emission Cycle and Duration are the number of hours between
rem   emission start cycles.  A zero value means that the emissions are not cycled.
rem   When non-zero, the number of emission hours is repeated again at QCYCLE hours
rem   after the starting emission time specified in the input Control file.

rem ECHO  QCYCLE = 7.0, >>SETUP.TXT
ECHO  QCYCLE = 1.0, >>SETUP.TXT
rem ECHO  QCYCLE = 0.0, >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KRND (6) - at this interval in hours, enhanced puff merging takes place.
rem   Enhanced merging is less restrictive and will degrade the accuracy of the
rem   simulation.  Puffs can be further apart and still be merged into the same
rem   position.  Less frequent merging will improve accuracy, however too many
rem   puffs may remain and the simulation time will be substantially increased.
rem   The selection of an appropriate value depends if the pollutant release is
rem   instantaneous or continuous.  Enhanced merging only occurs when the puff
rem   number exceeds 25% of MAXPAR.

ECHO  KRND    = 6,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   FRME (0.10) - is the fraction of the total mass that represents a puff mass at
rem   which all puffs with a mass less that puff value will only account for FRME of
rem   the total mass.  These Low Mass puffs will be subject to enhanced merging.

ECHO  FRME    = 0.1,     >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   FRMR (0.0) - is the fraction of the mass that is permitted to be removed at
rem   KRND intervals.  The normal situation is to permit no mass loss.  However
rem   for certain simulations, such as when a pollutant has a high ambient
rem   background relative, a small removal rate will significantly reduce the
rem   number of puffs on the grid at no loss in accuracy.

ECHO  FRMR    = 0.0E+00, >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem 	KSPL (1) - (a new parameter in the Nov 15 2007 pc update) is the standard
rem   splitting and merging interval (hours). The default is 1.0, i.e., the splitting
rem	  and merging take place every hour. If KSPL = 2.0, then these procedures take
rem 	place every 2 hours, etc.

ECHO  KSPL	  = 1, 	>>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem 	rounding parameters for merge -- now in this namelist in the Nov 15 2007 pc update

rem standard horizontal puff rounding fraction for merge (default = 1.00)
ECHO  FRHS   = 1.00, 	>>SETUP.TXT

rem vertical puff rounding (default = 0.02)
rem ECHO  FRVS   = 0.02, 	>>SETUP.TXT
rem Roland changed default for this to 0.01 in Oct 2008 version
ECHO  FRVS   = 0.01, 	>>SETUP.TXT

rem temporal puff rounding (default = 0.10)
ECHO  FRTS   = 0.10, 	>>SETUP.TXT

rem note that in current version, the corresponding parameters for enhanced merging
rem are simply set at 2.0 x the values above

rem ---------------------------------------------------------------------------------
rem   DELT (0.0) - is used to set the integration time step to a fixed
rem   value in minutes from 1 to 60.  It should be evenly divisible into 60.
rem   The default value of zero causes the program to compute the time step
rem   each hour according to the maximum wind speed, meteorological and
rem   concentration grid spacing, and the TRATIO parameter.  The fixed time
rem   step option should only be used when strong winds in regions not relevant
rem   to the dispersion simulation (perhaps the upper troposphere) are causing
rem   the model to run with small time steps.  Improper specification of the time
rem   step could cause aliasing errors in advection and underestimation of
rem   air concentrations.

rem ECHO  DELT = 60.0, >>SETUP.TXT

rem ECHO  DELT = 6.0, >>SETUP.TXT

ECHO  DELT = 20.0, >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem INCLUDED IN NAMELIST SETUP, but no longer used
rem   ISOT (0) - Internal Turbulence Parameterization - is a flag used to set the
rem   turbulence computational method. The default standard method computes the
rem   mixing using a diffusivity approach based upon vertical stability estimates
rem   and the horizontal wind field deformation. In shorter-range dispersion
rem   simulations (<100 km) the deformation parameterization used in conjunction
rem   with larger scale meteorological fields will not reflect the diurnal
rem   variations in horizontal turbulence. In this situation it is desirable
rem   to use the short-range parameterization in which the turbulent velocities
rem   are computed directly from the stability parameters.  The input TKE
rem   (turbulent kinetic energy) option replaces the models computation of
rem   stability with the TKE field from the input meteorological data set.
rem   Currently only the ETA forecast model data contain the TKE field.
rem   In the variance option, the input data is assumed to contain the
rem   3-dimensional component velocity variance fields.  Normally when
rem   turbulent fluxes (heat and momentum) are available, they are used to
rem   compute stability. The short-range method has an additional option (#2)
rem   to force the use of the profile to compute stability, rather than the fluxes.
rem   This may be desirable, especially if the fluxes represent averages rather
rem   than instantaneous values. Selection of an option inconsistent with the input
rem   meteorological data will result in the calculation using the default parameters.

rem   0  Standard: Vertical diffusivity and horizontal deformation
rem   1  Short Range: Horizontal and vertical velocity variances
rem   2  Same as ISOT=1 except forces the use of the profile to determine stability
rem   3 - Same as ISOT=0 except vertical mixing not averaged
rem   4  Input TKE: tubulence based upon input TKE field
rem   5  Input TKE: Same as ISOT=4 except Zi based upon TKE profile
rem   6  Variances: Velocity variances from input meteorological data file

rem ECHO  ISOT    = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   TKERD (0) - is the ratio of the vertical to the horizontal turbulence.
rem   A value of zero (the default) uses a TKER value consistent with the turbulence
rem   parameterization.  A non-zero value forces the vertical and horizontal values
rem   derived from the TKE to match the ratio. This option is only valid with ISOT=4
rem   and ISOT=5.  Currently this parameter cannot be edited through the GUI.

rem   In Nov 2006, Roland split this into Day and Night values...

rem  TKERD=0.18   ! day (unstable) turbulent kinetic energy ratio
rem  TKERN=0.18   ! night (stable) turbulent kinetic energy ratio
rem               ! ratio = w'2/(u'2+v'2)
rem 					! setting a non-zero value forces that ratio at all levels

ECHO  TKERD    = 0.18, >>SETUP.TXT
ECHO  TKERN    = 0.18, >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   TRATIO (0.75) - defines the fraction of a grid cell that a particle or
rem   trajectory is permitted to transit in one advection time step.
rem   Reducing this value will reduce the time step and increase computational times.
rem   Smaller time steps result in less integration error.  Integration errors
rem   can be estimated by computing a backward trajectory from the forward
rem   trajectory end position and computing the ratio of the distance between that
rem   endpoint and the original starting point divided by the total forward and
rem   backward trajectory distance.

ECHO  TRATIO  = 0.75,    >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   MGMIN (10) (Meteorological Sub-grid Size) is the minimum size in grid units
rem   of the meteorological sub-grid. The sub-grid is set dynamically during the
rem   calculation and depends upon the horizontal distribution of end-points and
rem   the wind speed.  Larger sub-grids than necessary will slow down the
rem   calculation by forcing the processing of meteorological data in regions where
rem   no transport or dispersion calculations are being performed.  In some
rem   situations, such as when the computation is between meteorological data files
rem   that have no temporal overlap, the model may try to reload meteorological data
rem   with a new sub-grid.  This will result in a fatal error.  One solution to this
rem   error would be to increase the minimum grid size larger than the meteorological
rem   grid to force a full-grid data load.

ECHO  MGMIN   = 10,      >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   Vertical Grid Coordinate System
rem   KMSL (0) - sets the default for input heights to be relative to the terrain
rem   height of the meteorological model.  Hence input heights are specified as AGL.
rem   Setting this parameter to 1" forces the model to subtract the local terrain
rem   height from source input heights before further processing. Hence input
rem   heights should be specified as relative to Mean Sea Level (MSL).  In
rem   concentration simulations, the MSL option also forces the vertical
rem   concentration grid heights to be considered relative to mean sea level.

ECHO  KMSL    = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   CPACK (1) - Concentration Packing - is the flag to turn off (set to 0)
rem   concentration output packing.  The default is to write the binary
rem   concentration file at only those grid points that have a non-zero
rem   concentration value (set to 1).  Setting the flag to zero results in
rem   output of the entire concentration grid.  Due to the nature of the
rem   packing method, if the plume covers more than 50% of the concentration grid,
rem   the default concentration packing will result in larger output file than
rem   an unpacked concentration file. A special concentration packing option
rem   (set to 2) can be defined to create an irregular grid (such as sampling
rem   locations). Setting this option forces the model to treat each concentration
rem   grid definition as a sampling location (pseudo grid point) in a single output
rem   file.  In this situation there is no limit to the number of sampling
rem   locations that can be defined through the grid definition section of the
rem   CONTROL file.  However, the characteristics of all grids must be defined
rem   and they must be the same, otherwise the results may be unpredictable.

ECHO  CPACK   = 1,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   ICHEM (0) - chemistry module selection index - see options below
rem   Conversion Modules -- Changes the models internal configuration in how it treats
rem   the pollutants. Some conversion options require additional modules and specific
rem   requirements in setting up the CONTROL file.  See the linked discussion under
rem   each option for more information.

rem   0=none
rem   1=matrix
rem   2=10% / hour
rem   3=PM10 dust storm simulation
rem   4=Set concentration grid identical to the meteorology grid (not in GUI)
rem   5=Deposition Probability method
rem   6=Puff to Particle conversion (not in GUI)
rem   7=Surface water pollutant transport

ECHO  ICHEM   = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   EFILE (null) - file name that contains point-source temporal emission
rem   factors, where each record contains the {year month day hour duration
rem   latitude longitude emission-rate} of each emission period (including the
rem   first one defined in the CONTROL file, in the following format:
rem   (I4,2I3,2I5,F6.2,F8.2,F8.0).  Note the hour and duration fields should
rem   be four characters long (0000), representing hours | minutes.

rem ECHO  EFILE   =  ,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   Ensemble Configuration Values - Sets the dimensions at which the meteorological
rem   grid will be offset for the ensemble calculation.  Only one offset (+ or -)
rem   in either X, Y, or Z is applied per member.
rem ---------------------------------------------------------------------------------
rem   DXF (1.0) - west to east grid factor for offsetting the meteorological grid in
rem   the ensemble calculation.

ECHO  DXF     = 1.0,     >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   DYF (1.0) - south to north grid factor for offsetting the meteorological grid in the ensemble calculation

ECHO  DYF     = 1.0,     >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   DZF (0.01) - vertical grid factor for ensemble (0.01 ~ 250m)

ECHO  DZF     = 0.01, >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   Particle Dump Intervals -->
rem ---------------------------------------------------------------------------------
rem   PINPF (PARINIT)  - default name for the particle dump input file.

ECHO  PINPF   = 'PARINIT',  >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   POUTF (PARDUMP) - default name for the particle dump output file.

ECHO  POUTF   = 'PARDUMP',  >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NINIT  sets the type of initialization performed.  When set to 0 no particle
rem   initialization occurs even if the PINPF file is found in the root directory.
rem   A value of 1 reads the file only during the initialization process.  No
rem   initialization will occur if the time of the particle dump does not match the
rem   time of the model initialization.  A value of 2 will check the file each hour
rem   during the simulation, and if the times match, the particles will be added to
rem   those already contained in the simulation.  A value of 3 is similar to the
rem   previous case, except the particles in the file replace all the particles
rem   in the simulation.

ECHO  NINIT   = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NDUMP (0) - can be set to dump out all the particle/puff points at selected
rem   time intervals to a file called PARDUMP.  This file can be read from the root
rem   directory at the start of a new simulation to continue the previous calculation.
rem   Valid NDUMP settings are [0] for no I/O or [hours] to set the number of hours
rem   from the start of the simulation at which all the endpoint positions will be
rem   written to the file.  The file must exist in the root directory and NDUMP>0
rem   for the model to initialize pollutant particles from the file.  NDUMP is used
rem   in conjunction with NCYCL (see below).

ECHO  NDUMP  = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NCYCL (0)- sets the cycle interval at which the PARDUMP file is to be written
rem   after the first write at hours NDUMP.  Multiple outputs will overwrite the last
rem   output.  For instance in a multi-day simulation, one application would be to
rem   set NDUMP=24 and NCYCL=24 to output all points at the end of every simulation day.
rem   If the model were to crash unexpectedly, the simulation could be restarted from
rem   the last PARDUMP output.

ECHO  NCYCL  = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KAGL -- this is used in the trajectory simulations... I think it specifies how the
rem   trajectory heights are displayed on the output graphs...
rem   -- starting position saved for plotting at initial time for all start points

rem ECHO  KAGL    = 0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KPUFF (0) - Puff Dispersion Parameterization - is the flag to use either the
rem   linear with time (0) or the square-root with time (1) dispersion equation for
rem   the horizontal growth rate of puffs.  This parameter does not affect
rem   particle dispersion.

ECHO  KPUFF  = 0,        >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KMIXD (0) - Mixed Layer Depth (new July-Aug 2008)
rem     0 = use input data MIXD if available, otherwise compute
rem     1 = compute from temperature profile
rem     2 = compute from TKE profile
rem     >= 10 use this value as a constant

ECHO  KMIXD  = 0,        >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KMIX0 (250) - Minimum Mixing Depth (new July-Aug 2008)

ECHO  KMIX0  = 250,      >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   SPLITF (1.0) - Size adjustment factor for horizontal splitting (new July-Aug 2008)
rem   1  automatic size adjustment factor
rem   <0 disable
rem   >1 use value

ECHO  SPLITF = 1.0,      >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   FRHMAX (3.0) - maximum value for the horizontal rounding parameter (new July-Aug 2008)

ECHO  FRHMAX = 3.0,      >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KDEF (0) - horizontal turbulence computation (new July-Aug 2008)
rem      0 - in proportion to the vertical turbulence
rem      1 - computed from the velocity deformation

ECHO  KDEF = 0,          >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NO LONGER USED, and DELETED FROM SETUP
rem   KZAV (0) - vertical mixing averaging method
rem      0 - Vertical diffusivity PBL profile varies with height
rem      1 - Vertical diffusivity PBL single average value

rem ECHO  KZAV = 0,          >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem new in Oct 2008 version
rem   KZMIX=0      ! vertical mixing adjustments
rem                ! 0 - NONE vertical diffusivity in PBL varies with height
rem                ! 1 - Vertical diffusivity in PBL single average value
rem                ! 2 - scale boundary-layer values by TVMIX
rem                ! 3 - scale free-troposphere values by TVMIX

ECHO  KZMIX = 0,         >>SETUP.TXT


rem ---------------------------------------------------------------------------------
rem new in Oct 2008 version
rem   TVMIX=1.0    ! vertical mixing scale factor

ECHO  TVMIX = 1.0,       >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   KBLS (1) - boundary layer stability derived from
rem      1 - heat and momentum fluxes
rem      2 - wind and temperature profiles

ECHO  KBLS = 1,          >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem  no longer used and no longer in setup - replaced with KBLT
rem  KPBL (1) - boundary layer similarity parameterizations
rem      1 - Beljaars/Holtslag and Betchov/Yaglom
rem      2 - Kanthar/Clayson
rem      3 - TKE field from input meteorology data file
rem      4 - velocity variances from input meteorology

rem ---------------------------------------------------------------------------------
rem  KBLT=2       ! boundary layer turbulence parameterizations
rem               ! 1 - Beljaars/Holtslag and Betchov/Yaglom
rem               ! 2 - Kanthar/Clayson
rem               ! 3 - TKE field from input meteorology data file
rem               ! 4 - velocity variances from input meteorology

ECHO  KBLT = 2,        >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem  VSCALE (100.0)   -  vertical Lagrangian time scale (sec)
rem  HSCALE (10800.0) -  horizontal Lagrangian time scale (sec)

rem ECHO  VSCALE = 100.0,     >>SETUP.TXT
rem Roland changed default for this to 200.0 in Oct 2008 version
ECHO  VSCALE = 200.0,     >>SETUP.TXT
ECHO  HSCALE = 10800.0,   >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NEW in GEM-HYSPLIT code
rem   CONAGE (48) -- age of particle or puff in hours at which it is converted
rem   e.g., to global eulerian grid

rem temporarily change this to 12
ECHO  CONAGE = 48       >>SETUP.TXT
rem ECHO  CONAGE =12       >>SETUP.TXT

rem note -- since this is last entry, can't have comma...

rem ---------------------------------------------------------------------------------
rem   NO LONGER INCLUDED IN SETUP
rem   MAXLVL (35) - are the maximum number of meteorological data levels that can
rem   be input to the model.  This value exceeds all currently available
rem   meteorological data sets.

rem   MDC NOTE: this is no longer part of NAMELIST SETUP... it is now specified as
rem   a parameter in DEFGRID.INC and is named "MLVL"
rem   the value currently in DEFGRID.INC is "75"
rem   In any event, I will comment this out...
rem   ECHO  MAXLVL  = 35,        >>SETUP.TXT

rem ---------------------------------------------------------------------------------
rem   NO LONGER INCLUDED IN SETUP
rem   KSFC (2) - defines the vertical index of the internal meteorological data level
rem   that is considered to be the top of the surface layer.  This value is used for
rem   stability scaling computations.  The default index value of 2 is consistent
rem   with the default polynomial parameters that results in the height of the
rem   surface layer top to default to 75 m AGL.

rem   MDC NOTE: This variable is apparently no longer in the SETUP NAMELIST group...
rem   now, it is determined in the subroutine METLVL so that the surface layer is 75m
rem   So, I will comment this out...
rem   ECHO  KSFC    = 2        >>SETUP.TXT

rem ---------------------------------------------------------------------------------
ECHO  /   >>SETUP.TXT
rem ---------------------------------------------------------------------------------

del setup.cfg
rename setup.txt setup.cfg

rem pause

rem finished creating setup.cfg

rem ---------------------------------------------------------------------------------
rem create GEM setup namelist file
rem ---------------------------------------------------------------------------------

rem  namelist initialization
rem   NAMELIST/GEMPARM/HMIX,CFACT,CKON,CMIN,CMAX,VMIX,WFACT,KDIVG,KMASS,KINIT, &
rem                    GEMDUMP,GEMCONC,GEMZINT,KZBOT,KZTOP,KZAVG,WFREQ,IHOUR
rem   INQUIRE(FILE='GEMPARM.CFG',EXIST=FTEST)

del gemparm.txt

ECHO  ^&gemparm > gemparm.txt
rem now figured out how to ECHO an ampersand -- have to have a ^ in front!

rem -- horiz mixing at the equator
ECHO  HMIX=200000.0,    >> gemparm.txt

rem -- max vertical mixing (m2/s)
ECHO  VMIX=50.0,    >> gemparm.txt

rem -- conserve mass (0:skip 1:show 2:yes)
ECHO  KMASS=2,    >> gemparm.txt

rem  -- initialization (0:no 1:band 2:dewpt 3:dump 4:gbl37)
rem if KINIT < 0, then GEM routines not called...
rem ECHO  KINIT=-1    >> gemparm.txt
ECHO  KINIT=0,    >> gemparm.txt

rem -- initial field if kinit>3
ECHO  CKON=0.0,    >> gemparm.txt

rem -- regression fit minimum
ECHO  CMIN=0.0,    >> gemparm.txt

rem -- regression fit maximum
ECHO  CMAX=1.0E+25,    >> gemparm.txt

rem -- sensitivity to vertical vel
ECHO  WFACT=1.0,    >> gemparm.txt

rem -- 1 = compute W from divergence
rem -- 0 = just use vertical velocity in met data
ECHO  KDIVG=0,    >> gemparm.txt

rem -- daily 3D dump file
ECHO  GEMDUMP='gdump.bin',     >> gemparm.txt

rem -- concentration output file
ECHO  GEMCONC='gconc.bin',     >> gemparm.txt

rem -- vertically integrated concentration
ECHO  GEMZINT='zint.bin',      >> gemparm.txt

rem -- units conversion factor
ECHO  CFACT=1.0,     >> gemparm.txt

rem -- bottom output level index
rem ECHO  KZBOT=1,    >> gemparm.txt
rem KZBOT has to be zero to get DEPOSITION
ECHO  KZBOT=0,    >> gemparm.txt

rem -- top output level index
ECHO  KZTOP=5,     >> gemparm.txt

rem -- 0:levels  1:average  2:integral  3:(2+0)  4:(2+1)
ECHO  KZAVG=0,     >> gemparm.txt

rem -- output frequency in hours
ECHO  WFREQ=24,     >> gemparm.txt

rem -- initial output hour
ECHO  IHOUR=0     >> gemparm.txt
rem note -- since this is last entry, can't have comma...

rem ---------------------------------------------------------------------------------
ECHO  /   >>GEMPARM.TXT
rem ---------------------------------------------------------------------------------

rem done with GEMPARM.TXT

del gemparm.cfg
rename gemparm.txt gemparm.cfg

rem pause

:end_gemparm_setup

rem **********************************************************************
rem \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
rem **********************************************************************
rem   ESTABLISH Hg_setup.CFG FILE
rem **********************************************************************
rem   The Hg_SETUP.CFG namelist file is not required, and if not present in the root
rem   startup directory, default values are used.  These parameters can all be
rem   changed without recompilation by modification of the contents of Hg_SETUP.CFG
rem   and in some cases their modification will substantially change the nature
rem   of the simulation. The configuration file should be present in the root
rem   directory.

rem   Note that for the following parameters, only value is used in the current
rem   version of the code. However, with a small amount of additional programming,
rem   additional values (e.g., locationally dependent) could be used.

rem	NAMELIST/Hg_SETUP/pcon,pden,ndist,nrange,method_lwc,method_dry,   &
rem							method_cl2_estm,method_cl2_mass,method_elem_dep, &
rem							cepdelta, mdcdelta, maxmiss, zrh_crit_surface, &
rem							zrh_crit_aloft,zrh_crit_stop

rem **********************************************************************

del hg_setup.txt

ECHO  ^&Hg_SETUP >hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   rxn_conc_dir - directory for gridded reactant conc data
rem	this is tied to read statements in "get_global_conc.f"
rem 	a new namelist entry, started in hg_set_005.bat

ECHO  rxn_conc_dir = 'c:\hysplit4\gridded_chem_data\1999_global_EMEP_data\',	   >>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   npath (5) - npath is the number of deposition paths tracked in
rem   depelm_hg: 1. dry gas; 2. dry particle; 3. wet gas;
rem   4. wet below cloud particle; 5. wet in cloud particle

ECHO  npath = 5,	   >>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   nland (20) - nland is the number of landtypes used in dry deposition
rem   algorithms... normal hysplit has 11 land categories. For Hg simulation
rem   have added land types 12 through 20 to deal with saline water
rem   chlorine issues (e.g., estimation of reactive chlorine Cl2);
rem   12-18 are additional water types; 19-20 are ice / snow

ECHO  nland = 20,	   >>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   pcon (3.9E-05) - pcon is the overall dry aerosol mass concentration, g/m3. This is
rem   used in the estimation of vapor/particle and vapor/droplet partitioning calculation.

ECHO  pcon = 3.9E-05,	   >>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   pden (2.0) - pden is the density of dry aerosol particles, g/cm3. This is
rem   used in the estimation of characteristics of the aerosol size distribution, used
rem   in vapor/particle and vapor/droplet partitioning calculation, and in dry deposition
rem   estimates.

ECHO  pden = 2.0,	   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   ndist (1) - ndist is the number of particle size distributions. Currently only one
rem   is used in the simulation, but additional distributions could be defined.

ECHO  ndist = 1, 	   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   nrange (14) - 	nrange  is the number of particle size distribution ranges. These
rem   are defined in the subroutine PSD_SETUP.

ECHO  nrange = 14,	  		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   method_lwc (6) - method_lwc is the method for estimation of liquid water content.
rem   Currently, there are 6 methods defined. For more details see subroutine LWC_ESTM

ECHO  method_lwc = 6,  		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   method_dry (6) - method_dry is the methodology for estimating dry deposition.
rem   the methods below were established in previous versions of hysplit_hg. They
rem   have not all necessarily been established yet in this new version of hysplit_hg.

rem  METHOD 1: Original HYSPLIT 4

rem  METHOD 2: Essentially the method used in Mark Cohen's VPFIN5F.for,
rem    except that the modifications to RA in HYSPLIT_4 have been included;
rem    RB calc is as used in VPFIN5f, except that ubar is replaced
rem    by vel(1), the mean horiz velocity at the first model level;
rem    RC calc has been changed slightly, as was done in vpfin5f in order
rem    that small terms are really small and large terms are really large.

rem  METHOD 3: Same as Method 2 for all land categories. For water,
rem    the method of Slinn and Slinn is used (1980, Atmos Envr 14: 1013-1016)
rem    However, no correction for humidity-induced particle growth has been
rem    included in this version; also, the diffusiophoresis term has been
rem    neglected

rem  METHOD 4: In this method, the "best" method identified by the EPA
rem    in Development and Testing of Dry Deposition Algorithms, 1993
rem    (EPA-454/R-92-017) OAQPS, Scire et al. is used. For PARTICLES, this
rem    is the ADOM-2 method. The ADOM method for particles is basically
rem    the HYSPLIT method for Ra, and a modified Slinn and Slinn method for Rb,
rem    for both water and non-water surfaces. In the Rb formulation,
rem    a modified (less severe) dependence on Stokes number is used.
rem    In addition, a 0.01 cm/sec phoretic velocity component is added
rem    to the deposition velocity to attempt to account for
rem    thermophoresis, diffusiophoresis, and electrophoresis.
rem    Also, in the exponent on the Schmidt Number, a value of -0.5 is
rem    used for roughness lengths less than 10 cm, and a value of
rem    -0.7 is used for roughness lengths greater than 10 cm.
rem    For GASES, no comparisons or recommendations were made in the EPA
rem    analysis; so, for gases, this subroutine will use the basic
rem    vpfin5f (with corrected Ra, and modified Rb and Rc) for land and water.

rem  METHOD 5: For PARTICLES over WATER, the method of Williams, 1982,
rem    Atmos Envr 16: 1933-1938, is used. For GASES over water, the basic
rem    vpfin5f method is used (METHOD 2 above). Over LAND, the basic
rem    vpfin5f method is also used (METHOD 2 above).

rem  METHOD 6: Same as Method 3, except that humidity induced particle growth
rem    has been included for deposition to water.

ECHO  method_dry = 6,   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   method_cl2_estm (3) - method_cl2_estm is the the method for estimating Cl2tot.
rem 		1 - is original method.
rem   	2 - is orig method with diurnal variation
rem      3 - method devised for EMEP-III using ocean and saline water land use data

ECHO  method_cl2_estm = 3, 	>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   method_cl2_mass (2) - method_cl2_mass is the the method for estimating Cl2 mass.
rem 		1 - is orig gas = const
rem   	2 - is new cl2tot = const

ECHO  method_cl2_mass = 2, 	>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   method_elem_dep (1) - method_elem_dep is the method used for estm elem Hg dep
rem 		0 - elem dep set to zero
rem   	1 - elem dep calculated as normal

ECHO  method_elem_dep = 1, 	>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   cepconc_delta (1440) - cepconc_delta is the time step for conc/flux output at
rem   user defined locations (minutes)
rem   1440 = 24 hours; 2880 = 48 hours; 40320 = 672 hrs = 4 weeks

rem ECHO  cepconc_delta = 1440,   		>>hg_setup.txt
ECHO  cepconc_delta = 1440,   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   dep_delta (x) - dep_delta is time step for deposition outputs to user defined receptors
rem   1440 = 24 hours; 2880 = 48 hours; 40320 = 672 hrs = 4 weeks

rem ECHO  dep_delta = 1440,   		>>hg_setup.txt
ECHO  dep_delta = 1440,   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   maxmiss (15) - maxmiss is the # of time periods that can be missed before
rem   the program stops. Had been hardwired at 1 at least in early version of
rem   HYSPLIT_4, but, this was too restrictive for at least some of the data sets
rem   Need to determine status is current version of HYSPLIT...

ECHO  maxmiss = 15,   			>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   zrh_crit_surface (0.98) - zrh_crit_surface is the critical RH for establishing
rem   bottom of cloud in the surface layer

ECHO  zrh_crit_surface = 0.98,  	>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   zrh_crit_aloft (0.90) - zrh_crit_aloft is the critical RH for establishing
rem   bottom of cloud in all layers above the surface layer

ECHO  zrh_crit_aloft = 0.90,   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
rem   zrh_crit_stop (0.80) - zrh_crit_stop is the critical RH for establishing
rem   the top of the cloud layer

ECHO  zrh_crit_stop = 0.80   		>>hg_setup.txt

rem ---------------------------------------------------------------------------------
ECHO  /   >>hg_setup.txt
rem ---------------------------------------------------------------------------------

del hg_setup.cfg
rename hg_setup.txt hg_setup.cfg

rem pause

:end_hg_setup

rem finished creating hg_setup.cfg

del cdump.bin

rem by using >> operator, can get output in file but not on screen
rem note -- also have "2>&1" which also directs "STDERR" to "STDOUT" which is then
rem written to output file
rem this creates a blank file for screen output:
rem but for now, don't create
rem type %9_screen.out > %9_screen.out

rem DUMP SCREEN OUTPUT TO FILE
rem e:\hysplit4_hg04_global\exec_f90\hymodelg >> %9_screen.out 2>&1

rem DON'T DUMP SCREEN OUTPUT TO FILE


rem *****************************************
rem %8 program code
rem *****************************************

rem    1 = basic HYSPLIT without GEM

rem    2 = basic HYSPLIT with GEM

rem    3 = HYSPLIT-HG without GEM

rem    4 = HYSPLIT-HG with GEM

rem *****************************************

if %8==1 goto program_1
if %8==2 goto program_2
if %8==3 goto program_3
if %8==4 goto program_4

:program_1
c:\hysplit4\exec\hycs_std
goto end_program

:program_2
c:\hysplit4\exec\hycs_gem
goto end_program

:program_3
c:\hysplit4\exec\hymodelc_hg05_ver_14_mdp

rem pause

c:\hysplit4\exec\rdp_sum_06

rename recpsum_1.out      %9_rs06.rs1
rename recptime_1.out     %9_DEPOSITION.txt

rem will not go into recpsum_2, recpsum_3 in this training
rem so will delete these here
del recpsum_2.out      %9_rs06.rs2
del recpsum_3.out      %9_rs06.rs3
rem rename recpsum_2.out      %9_rs06.rs2
rem rename recpsum_3.out      %9_rs06.rs3

rem pause

goto end_program

:program_4
c:\hysplit4\exec\hymodelc_hg05_ver_13_mdc

c:\hysplit4\exec\rdp_sum_06

rename recpsum_1.out      %9_rs06.rs1
rename recptime_1.out     %9_DEPOSITION.txt

rem will not go into recpsum_2, recpsum_3 in this training
rem so will delete these here
del recpsum_2.out      %9_rs06.rs2
del recpsum_3.out      %9_rs06.rs3
rem rename recpsum_2.out      %9_rs06.rs2
rem rename recpsum_3.out      %9_rs06.rs3

goto end_program

:end_program

rem first collect all shape input files into zip file
rem for workshop in Mexico, they will probably not have WinZip Command Line
rem so will not do this...
rem wzzip -ybc shp_inputs.zip shp_input_????_*.txt
rem wzzip -ybc shp_inputs.zip ascii2shp_batch_file.bat
rem del ascii2shp_batch_file.bat
rem del shp_input_????_*.txt
rem rename shp_inputs.zip 		%9_shp_inputs.zip

rem these are common outputs for all runs:
rename control.     			%9.ctr
rename setup.cfg   			  %9.cfg
rename conc.cfg           %9.ccf
rename message.     			%9.msg
rename cdump.bin    			%9.cdp

if %8==1 goto results_1
if %8==2 goto results_2
if %8==3 goto results_3
if %8==4 goto results_4

rem ****************************************
:results_1
rem there are no additional outputs
goto end_results

rem ****************************************
:results_2
rename gemparm.cfg        %9.gem
rename gdump.bin          %9.gdp
rename gconc.bin          %9.gcn
goto end_results

rem ****************************************
:results_3
rename hg_setup.cfg       %9.hfg
rename recpmass.out       %9.rdp
rename cepflux.out        %9.flx
rename sizedist2.out      %9.sd2
rename sizedist.out       %9.sd1
rem rename recpsum_1.out      %9.rs1
rem rename recpsum_2.out      %9.rs2
rem rename recpsum_3.out      %9.rs3
mkdir ascii2shp_inputs
move shp_input_????_*.txt ascii2shp_inputs
move ascii2shp_batch_file.bat ascii2shp_inputs
rem the following have not been implemented yet
rem so for now will delete empty output files
del cepconc.out
del cepmet.out
del recpmet.out
rem rename cepconc.out        %9.cep
rem rename recpmet.out        %9.rmt
rem rename cepmet.out         %9.cmt
rename cep_summary.out  	%9.clt
rename recp_summary.out 	%9.rla
rename recp_detail.out 		%9.rlb
rem rename sizedist.out 			%9.ps1
rem rename sizedist2.out 		  %9.ps2
rename hg_out.*				    %9.*
goto end_results

rem ***************************************
:results_4
rename hg_setup.cfg       %9.hfg
rename recpmass.out       %9.rdp
rename cepflux.out        %9.flx
rename sizedist2.out      %9.ps2
rename sizedist.out       %9.ps1
rem rename recpsum_1.out      %9.rs1
rem rename recpsum_2.out      %9.rs2
rem rename recpsum_3.out      %9.rs3
mkdir ascii2shp_inputs
move shp_input_????_*.txt ascii2shp_inputs
move ascii2shp_batch_file.bat ascii2shp_inputs
del cepconc.out
del cepmet.out
del recpmet.out
rename cep_summary.out  	%9.clt
rename recp_summary.out 	%9.rla
rename recp_detail.out 		%9.rlb
rename sizedist.out 			%9.ps1
rename sizedist2.out 		  %9.ps2
rename hg_out.*				    %9.*
rename gemparm.cfg        %9.gem
rename gdump.bin          %9.gdp
rename gconc.bin          %9.gcn
goto end_results

rem **************
:end_results
rem **************

rem will commment out the winzip command line statements here
rem wzzip -ybc temp.zip 			%9.*
rem wzzip -ybc temp.zip 			%9_shp_inputs.zip
rem del %9_shp_inputs.zip

rem wzzip -ybc temp.zip  %9_screen.out

if %8==1 goto plot_1
if %8==2 goto plot_2
if %8==3 goto plot_3
if %8==4 goto plot_4

rem    1 = basic HYSPLIT without GEM

rem    2 = basic HYSPLIT with GEM

rem    3 = HYSPLIT-HG without GEM

rem    4 = HYSPLIT-HG with GEM

rem *********************
rem  DO GRIDPLOT
rem *********************

rem E:\hysplit4_mdc\hysplit4_hg05\working>gridplot
rem  USAGE: gridplot -[options(default)]
rem    -i[input file name (cdump.bin)]
rem    -o[output name (plot)]
rem    -l[lowest interval value (1.0E-36)]
rem    -m[multi frames one file (0)]
rem    -d[delta interval value (1000.0)]
rem    -s[species number to display: (1); 0-sum]
rem    -h[height of level to display (m) (integer): (0 = dep)]
rem    -a[scale: 0-linear, (1)-logarithmic]
rem    -x[longitude offset (0), e.g., -90.0: U.S. center; 90.0: China center]
rem    -f[(0), 1-ascii text output files for mapped values]

rem **********************
rem  DO CONCPLOT
rem **********************

rem E:\hysplit4_mdc\hysplit4_hg05\working>concplot
rem  USAGE: concplot -[options (default)]
rem    -a[Arcview GIS: 0-none 1-log10 2-value 3-GoogleEarth]
rem    -b[Bottom display level: (0) m]
rem    -c[Contours: (0)-dyn/exp 1-fix/exp 2-dyn/lin 3-fix/lin 4-set 50-0,interval 10 51-1,interval 10]
rem    -d[Display: (1)-by level, 2-levels averaged]
rem    -e[Exposure units flag: (0)-concentrations, 1-exposure, 2-threshold, 3-hypothetical volcanic ash]
rem    -f[Frames: (0)-all frames one file, 1-one frame per file]
rem    -g[Circle overlay: ( )-auto, #circ(4), #circ:dist_km]
rem    -h[Hold map at center lat-lon: (source point), lat:lon]
rem    -i[Input file name: (cdump)]
rem    -j[Graphics map background file name: (arlmap) or shapefiles.txt]
rem    -k[Kolor: 0-B&W, (1)-Color, 2-No Lines Color, 3-No Lines B&W]
rem    -l[Label options: ascii code, (73)-open star]
rem    -L[LatLonLabels: none=0 auto=(1) set=2:value(tenths)]
rem    -m[Map projection: (0)-Auto 1-Polar 2-Lamb 3-Merc 4-CylEqu]
rem    -n[Number of time periods: (0)-all, numb, min:max, -incr]
rem    -o[Output file name: (concplot.ps)]
rem    -p[Process file name suffix: (ps) or process ID]
rem    -q[Quick data plot: ( )-none, filename]
rem    -r[Removal: 0-none, (1)-each time, 2-sum, 3-total]
rem    -s[Species: 0-sum, (1)-select, #-multiple]
rem    -t[Top display level: (99999) m]
rem    -u[Units label for mass: (mass), see "labels.cfg" file]
rem    -v[Values[:labels (optional)] for fixed contours: val1:lab1+val2:lab2+val3:lab3+val4:lab4]
rem    -w[Grid point scan for contour smoothing (0)-none 1,2,3, grid points]
rem    -x[Concentration multiplier: (1.0)]
rem    -y[Deposition multiplier:    (1.0)]
rem    -z[Zoom factor: 0-least zoom, (50), 100-most zoom]

rem  NOTE: leave no space between option and value

rem Another mapping option would be to specify a
rem special pointer file, always called shapefiles.txt to replace
rem the map background file arlmap in the -j command line option (see above).
rem This file would contain the name of one or more shapefiles
rem that can be used to create the map background.
rem The line characteristics (spacing, thickness, color)
rem can be specified for each shapefile following the format specified below:

rem Record format: 'file.shp' dash thick red green blue
rem file.shp = /dir/name of input shapefile in quotes
rem dash = {0} for solid; {dashes}/in; <0 color fill
rem thick = line thickness in inches (default = 0.0)
rem Red Green Blue = RGB values (0.0 0.0 0.0 is black)
rem Record example for default: 'arlmap.shp' 0 0.005 0.4 0.6 0.8

rem **********
:plot_1
:plot_3
rem **********

c:\hysplit4\exec\gridplot -s0 -i%9.cdp -h0 -f1 -o%9_gridplot_c -m0 -d10.0 -l1.0E-15

rem c:\hysplit4\exec\concplot -jlakes_rivers.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-07+1.0E-08+1.0E-09+1.0E-10

rem getting error after ~19 maps, will try without shapefiles
rem c:\hysplit4\exec\concplot -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-07+1.0E-08+1.0E-09+1.0E-10

rem getting error with rivers and lakes... even if called shapefile.txt... will just do lakes and ARL_MAP
rem c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-08+1.0E-09+1.0E-10+1.0E-11

rem try 6,7,8,9
rem c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-06+1.0E-07+1.0E-08+1.0E-09

rem try -c0 -- dynamic - exp
rem c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c0

rem c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-08+1.0E-10+1.0E-12+1.0E-14

rem try -c0 -- dynamic - exp
c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c0

rename HYSPLIT_ps.kml %9.kml
rename gistmp*.txt %9_gistmp.txt
rename GELABEL_ps.txt %9_GELABEL.txt

goto plot_end

rem **********
:plot_2
:plot_4
rem **********

rem add puff and gem grids together
c:\hysplit4\exec\concadd -i%9.cdp -b%9.gcn -o%9.tot

rem first do puff results
c:\hysplit4\exec\gridplot -s0 -i%9.cdp -h0 -f1 -o%9_gridplot_c -m0 -d10.0 -l1.0E-15

rem now do for GEM output file
c:\hysplit4\exec\gridplot -s0 -i%9.gcn -h0 -f1 -o%9_gridplot_g -m0 -d10.0 -l1.0E-15

rem now do for combined puff + GEM output file
c:\hysplit4\exec\gridplot -s0 -i%9.tot -h0 -f1 -o%9_gridplot_t -m0 -d10.0 -l1.0E-15

rem now do concplot for puff results
c:\hysplit4\exec\concplot -jshapefiles.txt -s0 -a3 -f0 -i%9.cdp -o%9_concplot_c_ -t0 -c4 -v1.0E-07+1.0E-08+1.0E-09+1.0E-10
rename HYSPLIT_ps.kml %9.kml
rename gistmp*.txt %9_gistmp.txt
rename GELABEL_ps.txt %9_GELABEL.txt

goto plot_end

:plot_end

mkdir %9_results
move %9.* %9_results
move %9*.* %9_results
move ascii2shp_inputs %9_results
